@@ -19,6 +19,7 @@
  * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * 
+ * $Id: audiolib.h,v 1.4 2002/10/24 02:46:14 jon Exp $
  * $NCDId: @(#)audiolib.h,v 1.67 1995/12/28 19:46:49 greg Exp $
  * 
  * <audio/audiolib.h>
@@ -34,9 +35,13 @@
  *				    VERSION				     *
  *****************************************************************************/
 
-#define AudioLibraryVersion	2
 
 
+#define AudioLibraryVersionMajor        2
+#define AudioLibraryVersionMinor        3
+#define AudioLibraryVersionTeeny        0
+
+#define AudioLibraryVersion             AudioLibraryVersionMajor
 
 /*****************************************************************************
  *			    GET NEEDED HEADER FILES			     *
@@ -1669,7 +1674,7 @@ _AUFUNCPROTOEND
  * that errors in the open procedure are handled.
  */
 
-#if defined(WIN32) && !defined(_OPENSVR_C_)
+#if defined(WIN32) && (!defined(_OPENSVR_C_) && !defined(__CYGWIN__))
 #define AuDefaultErrorHandler	(*AuDefaultErrorHandler_p)
 #define AuDefaultIOErrorHandler	(*AuDefaultIOErrorHandler_p)
 #endif /* WIN32 && !_OPENSVR_C_ */
